#define LINE_LEFT	0
#define LINE_RIGHT	1
#define LINE_TOP	2
#define LINE_BOTTOM	3


typedef struct
{
	chtype prevchar;
} prev_win_contents;

typedef struct
{
	WINDOW *win;

	int ocols, olines;	/* offset */
	int ncols, nlines;	/* number */

	prev_win_contents *pwc;
} NEWWIN;

int wait_for_keypress(int what_help);
void wrong_key(void);
char ask_yes_no(int what_help);
void color_on(WINDOW *win, int index);
void color_off(WINDOW *win, int index);
void draw_line(WINDOW *win, char where);
char * edit_string(WINDOW *win, int y, int win_width, int max_width, char numbers_only, char *input_string, int what_help);
NEWWIN * create_popup(int n_lines, int n_colls);
void delete_popup(NEWWIN *mywin);
void draw_marker_line(WINDOW *win);
void mydelwin(WINDOW *win);
void mydoupdate(WINDOW *win);
WINDOW * mynewwin(int nlines, int ncols, int begin_y, int begin_x);
void escape_print(WINDOW *win, int y, int x, char *str);
void win_header(WINDOW *win, char *str);
void gui_window_header(char *string);
